## Product Name
Toolbox to:
- automatize extraction of wind speed and wind turbine FC via the renewable.ninja API  (https://www.renewables.ninja/).
- build aggregated FC at the France level (B. Shirizadeh et al. https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3592447, https://github.com/BehrangShirizadeh/EOLES_elecRES )
- compare simulated wind turbine FC with the RTE experimental ones.
- plot the results with geographical representation

## Installation
Run the following to install:
```python
pip install vre_eoles 
```

## Usage example
**refer to** [image_features_extract-examples](https://github.com/Bertin-fap/EOLES_elecRES).


# Release History
0.1.0 

# Meta
	- François Bertin– francois.bertin7@wanadoo.fr 

Distributed under the [MIT license](https://mit-license.org/)

# About the authors
	- François Bertin retired, formally senior scientist at CEA-LETI